==> haskell-hashable-time-0.2.0.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hashable-time
version:              0.2.0.2
visibility:           public
id:                   hashable-time-0.2.0.2-6YFNtQpLnGLKMrHRc4VV74
key:                  hashable-time-0.2.0.2-6YFNtQpLnGLKMrHRc4VV74
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  2f7fe15fff8921c5d147cd06646cbe52
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-8.10.1/site-local/hashable-time-0.2.0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hashable-time-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/hashable-time-0.2.0.2
hs-libraries:         HShashable-time-0.2.0.2-6YFNtQpLnGLKMrHRc4VV74
depends:
    base-4.14.0.0 hashable-1.3.0.0-KxLg31LAX1D630cavk7ERb time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-time-0.2.0.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hashable-time
version:              0.2.0.2
visibility:           public
id:                   hashable-time-0.2.0.2-C2Jd7R6UDeM2gyg6aqItq1
key:                  hashable-time-0.2.0.2-C2Jd7R6UDeM2gyg6aqItq1
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  b8228fb6834866765f43617fac605bab
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-8.10.1/site-local/hashable-time-0.2.0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hashable-time-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/hashable-time-0.2.0.2
hs-libraries:         HShashable-time-0.2.0.2-C2Jd7R6UDeM2gyg6aqItq1
depends:
    base-4.14.0.0 hashable-1.3.0.0-LTNBlEjzerR9689SxHXUQO time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
